@@ -43,3 +43,6 @@ mod window_finder;
 
 pub use displays::enumerate_displays as enumerate_displays;
 pub use window_finder::get_capturable_windows as enumerate_windows;
+
+pub use displays::DisplayInfo;
+pub use window_finder::WindowInfo;
